@@ -23,7 +23,7 @@ import re
 import sys
 
 __pkgname__ = 'django-request-tree'
-__version__ = '0.6.1'
+__version__ = '0.7'
 
 class generate(object):
     def __init__(self, method):
@@ -95,6 +95,14 @@ class UnlessList(object):
     def __repr__(self):
         return self.is_list and self.l.__repr__() or self.d.__repr__()
 
+def data_check(datum):
+    try:
+        if '.' in datum:
+            return float(datum)
+        return int(datum)
+    except ValueError:
+        return datum
+
 
 def generate_tree(data):
     """Generates a tree structure from a flat list using a seperator"""
@@ -105,19 +113,51 @@ def generate_tree(data):
         while '_' in rest:
             (token, rest) = rest.split('_', 1)
             r = r[token]
-        r[rest] = data[name]
+        r[rest] = data_check(data[name])
 
     return result.norm()
 
 
+def validate_tree(data, schema):
+    """Generates a tree and then validates it against a schema"""
+    result = generate_tree(data)
+
+    # lazy import of xssd
+    if 'Validator' not in locals():
+        from xssd import Validator
+
+    if isinstance(schema, dict):
+        schema = Validator(schema)
+
+    return (result, schema.validate(result))
+
+
 if __name__ == '__main__':
     a = UnlessList()
-    print generate_tree( {
+    d = {
        'fruit_0_name': "banana",
        'fruit_0_colour': "yellow",
        'fruit_1_name': "apple",
        'fruit_1_colour': "red",
        'bread_name': "tigle",
-       'bread_type': "hairy",
+       'bread_type': "05",
+    }
+    (s, e) = validate_tree(d, {
+        'root': [
+          {'name':'fruit', 'type':'fruit', 'maxOccurs': 2},
+          {'name':'bread', 'type':'bread'},
+        ],
+        'complexTypes': {
+          'fruit': [
+            { 'name':'name',   'type':'string' },
+            { 'name':'colour', 'type':'string' },
+          ],
+          'bread': [
+            { 'name':'name', 'type':'string' },
+            { 'name':'type', 'type':'integer' },
+          ],
+        },
     })
+    print s
+    print e
 
